#------------------------------------------------------------------------------
# ConsoleSetLibPath.py
#   Initialization script for cx_Freeze which manipulates the path so that the
# directory in which the executable is found is searched for extensions but
# no other directory is searched. The environment variable LD_LIBRARY_PATH is
# manipulated first, however, to ensure that shared libraries found in the
# target directory are found. This requires a restart of the executable because
# the environment variable LD_LIBRARY_PATH is only checked at startup.
#------------------------------------------------------------------------------

import os
import sys
import warnings
import zipimport
import ConfigParser

fileName = sys.path[0]
while os.path.islink(fileName): fileName = os.path.realpath(fileName)
dirName = os.path.abspath( os.path.dirname(fileName) )
# reading oopath. Remark = sys.argv[0] does not work because we are not a python script
cp=ConfigParser.ConfigParser()
cp.read( os.path.join(dirName,'bibus.cfg') )
oopath = cp.get('PATH','oopath')
if not os.path.isabs(oopath):
	# the path is relative to bibus install directory (needed by portable version)
	oopath = os.path.abspath( os.path.join(dirName,oopath) )
	
if sys.platform.startswith('win'):
	LIBPATH = 'PATH'	# Windows
else:
	LIBPATH = 'LD_LIBRARY_PATH'	# linux (unix)
	
paths = os.environ.get(LIBPATH, "").split(os.pathsep)
if dirName not in paths:
    if oopath not in paths:
        paths.insert(0, oopath)
    paths.insert(0, dirName)
    os.environ[LIBPATH] = os.pathsep.join(paths)
    os.execv(sys.executable, sys.argv)

sys.frozen = True
sys.path = [fileName, dirName]

m = __import__("__main__")
importer = zipimport.zipimporter(fileName)
code = importer.get_code(m.__name__)
exec code in m.__dict__

